UGCStatisticType

Enum UGCStatisticType 

pub enum UGCStatisticType {
Show 13 variants Subscriptions, Favorites, Followers, UniqueSubscriptions, UniqueFavorites, UniqueFollowers, UniqueWebsiteViews, Reports, SecondsPlayed, PlaytimeSessions, Comments, SecondsPlayedDuringTimePeriod, PlaytimeSessionsDuringTimePeriod,
}
Available published item statistic types.

Variants



Subscriptions

The number of subscriptions.



Favorites

The number of favorites.



Followers

The number of followers.



UniqueSubscriptions

The number of unique subscriptions.



UniqueFavorites

The number of unique favorites.



UniqueFollowers

The number of unique followers.



UniqueWebsiteViews

The number of unique views the item has on its Steam Workshop page.



Reports

The number of times the item has been reported.



SecondsPlayed

The total number of seconds this item has been used across all players.



PlaytimeSessions

The total number of play sessions this item has been used in.



Comments

The number of comments on the items steam has on its Steam Workshop page.



SecondsPlayedDuringTimePeriod

The number of seconds this item has been used over the given time period.



PlaytimeSessionsDuringTimePeriod

The number of sessions this item has been used in over the given time period.