MatchmakingServers

Struct MatchmakingServers 

pub struct MatchmakingServers { /* private fields */ }
Access to the steam MatchmakingServers interface

Implementations

Source

impl MatchmakingServers

pub fn ping_server(&self, ip: Ipv4Addr, port: u16, callbacks: PingCallbacks)

pub fn player_details( &self, ip: Ipv4Addr, port: u16, callbacks: PlayerDetailsCallbacks, )

pub fn server_rules( &self, ip: Ipv4Addr, port: u16, callbacks: ServerRulesCallbacks, )

pub fn lan_server_list<ID: Into<AppId>>( &self, app_id: ID, callbacks: ServerListCallbacks, ) -> Arc<Mutex<ServerListRequest>>

Usage

Request must be released at the end of using. For more details see ServerListRequest::release

Arguments
  • app_id: The app to request the server list of.
pub fn internet_server_list<ID: Into<AppId>>( &self, app_id: ID, filters: &HashMap<&str, &str>, callbacks: ServerListCallbacks, ) -> Result<Arc<Mutex<ServerListRequest>>, ()>

Usage

Request must be released at the end of using. For more details see ServerListRequest::release

Arguments
  • app_id: The app to request the server list of.
  • filters: An array of filters to only retrieve servers the user cares about. A list of the keys & values can be found here.
Errors

Every filter’s key and value must take 255 bytes or under, otherwise Err is returned.

pub fn favorites_server_list<ID: Into<AppId>>( &self, app_id: ID, filters: &HashMap<&str, &str>, callbacks: ServerListCallbacks, ) -> Result<Arc<Mutex<ServerListRequest>>, ()>

Usage

Request must be released at the end of using. For more details see ServerListRequest::release

Arguments
  • app_id: The app to request the server list of.
  • filters: An array of filters to only retrieve servers the user cares about. A list of the keys & values can be found here.
Errors

Every filter’s key and value must take 255 bytes or under, otherwise Err is returned.

pub fn history_server_list<ID: Into<AppId>>( &self, app_id: ID, filters: &HashMap<&str, &str>, callbacks: ServerListCallbacks, ) -> Result<Arc<Mutex<ServerListRequest>>, ()>

Usage

Request must be released at the end of using. For more details see ServerListRequest::release

Arguments
  • app_id: The app to request the server list of.
  • filters: An array of filters to only retrieve servers the user cares about. A list of the keys & values can be found here.
Errors

Every filter’s key and value must take 255 bytes or under, otherwise Err is returned.

pub fn friends_server_list<ID: Into<AppId>>( &self, app_id: ID, filters: &HashMap<&str, &str>, callbacks: ServerListCallbacks, ) -> Result<Arc<Mutex<ServerListRequest>>, ()>

Usage

Request must be released at the end of using. For more details see ServerListRequest::release

Arguments
  • app_id: The app to request the server list of.
  • filters: An array of filters to only retrieve servers the user cares about. A list of the keys & values can be found here.
Errors

Every filter’s key and value must take 255 bytes or under, otherwise Err is returned.