Networking

Struct Networking 

pub struct Networking { /* private fields */ }
Access to the steam networking interface

Implementations

Source

impl Networking

pub fn accept_p2p_session(&self, user: SteamId) -> bool

Accepts incoming packets from the given user

Should only be called in response to a P2PSessionRequest.

pub fn close_p2p_session(&self, user: SteamId) -> bool

Closes the p2p connection between the given user

pub fn get_p2p_session_state(&self, user: SteamId) -> Option<P2PSessionState>

Gets the connection state to the specified user

Returns the P2P session state if a connection exists with the user, or None if no connection exists.

pub fn send_p2p_packet( &self, remote: SteamId, send_type: SendType, data: &[u8], ) -> bool

Sends a packet to the user, starting the connection if it isn’t started already

pub fn send_p2p_packet_on_channel( &self, remote: SteamId, send_type: SendType, data: &[u8], channel: i32, ) -> bool

Sends a packet to the user on a specific channel

pub fn is_p2p_packet_available(&self) -> Option<usize>

Returns whether there is a packet queued that can be read.

Returns the size of the queued packet if any.

pub fn is_p2p_packet_available_on_channel(&self, channel: i32) -> Option<usize>

Returns whether there is a packet available on a specific channel

pub fn read_p2p_packet(&self, buf: &mut [u8]) -> Option<(SteamId, usize)>

Attempts to read a queued packet into the buffer if there are any.

Returns the steam id of the sender and the size of the packet.

pub fn read_p2p_packet_from_channel( &self, buf: &mut [u8], channel: i32, ) -> Option<(SteamId, usize)>

Attempts to read a queued packet into the buffer from a specific channel